"use strict";
// Inspired by `make` by Matthew Crumley (silentmatt.com) https://stackoverflow.com/a/2947012
// Licensed under AGPL-3.0, check `LICENSE` for the full text.
Object.defineProperty(exports, "__esModule", { value: true });
exports.$el = void 0;
function $el(name, ...desc) {
    // Take off ID or class from the name
    let elementName = name;
    let className = "";
    let id = "";
    if (name.includes("#")) {
        [elementName, id] = name.split("#");
    }
    if (name.includes(".")) {
        [elementName, className] = name.split(".");
    }
    // Create the element and add the attributes (if found)
    const el = document.createElement(elementName);
    if (className) {
        el.className = className;
    }
    if (id) {
        el.id = id;
    }
    const attributes = desc[0];
    if (typeof attributes === "object" && !(attributes instanceof Node)) {
        for (const attr in attributes) {
            const value = attributes[attr];
            if (attr.startsWith("@")) {
                el.addEventListener(attr.substring(1), value);
            }
            else if (attr === "dataset") {
                for (const key in value) {
                    el.dataset[key] = value[key];
                }
            }
            else {
                el[attr] = value;
            }
        }
        desc.shift();
    }
    for (const item of desc) {
        el.appendChild(item instanceof Node ? item : document.createTextNode(item));
    }
    return el;
}
exports.$el = $el;
exports.default = $el;
